Предотвратить рак груди - Калифорнийские протоны
Description: Понимание основных причин и факторов риска рака груди является обязательным условием профилактики. Узнайте, подвержены ли вы риску и какие меры вы можете предпринять, чтобы предотвратить рак груди.

Предотвратить грудь
рак

Обзор

Диагностика

Лечение

Причины и риски

Этапы и оценки

# Знай причины.
Поймите свои риски.

Когда вам исполнится 20 лет, важно следить за своим здоровьем и регулярно обследовать грудь. Рак груди является наиболее распространенным женским раком во всем мире, и примерно у каждой восьмой женщины в Соединенных Штатах он будет диагностирован когда-нибудь в своей жизни. Этот процент увеличивается до 1% для тех, у кого есть BRCA1 мутация или BRCA2 мутация. Однако рак груди поддается лечению, особенно при раннем выявлении.

## Основные причины рака груди

Рак в значительной степени вызван мутациями или изменениями генетического материала, обнаруженного в ваших клетках. С некоторыми мутациями вы родились, а другие приобрели в более позднем возрасте из-за ошибок в процессе репликации генов. В большинстве случаев рак развивается, когда клетки прекращают свои обычные функции и начинают быстро расти, не могут остановить неконтролируемый рост клеток или совершают ошибки при исправлении ошибок ДНК. Имейте в виду, что не все приобретенные или унаследованные генетические мутации становятся раком.

## Общие факторы риска рака груди

Хотя врачи обнаружили некоторую корреляцию между определенными состояниями здоровья и диагностированными случаями, большинство случаев рака возникает у людей без каких-либо известных факторов риска. Ваш лучший подход - управлять тем, что вы можете контролировать, изменять то, что вы можете, и оставаться в курсе изменений в вашем здоровье, которые могут быть причиной рака груди.

- Возраст: Рак может развиться в любом возрасте, но 2 из 3 случаев инвазивного рака груди обнаруживаются у женщин 55 лет и старше.
- Раса / этническая принадлежность: Еврейское наследие ашкенази (восточноевропейское) может подвергнуть вас большему риску. У женщин европеоидной расы вероятность развития рака груди несколько выше, чем у женщин афроамериканского, латиноамериканского и азиатского происхождения. Однако у афроамериканок больше шансов заболеть более агрессивным раком груди в более молодом возрасте.
- Наследственные генетические мутации: BRCA1, BRCA2 и CHEC2 отклонения можно проследить до 5-10% всех случаев.
- История семьи: Ваш генетический риск рака груди удваивается, если у одного из родственников первой степени - сестры, матери или дочери - диагностирован рак груди. Если у вас были диагностированы два родственника первой степени родства, ваш риск в 5 раз выше среднего. Кровные родственники, которым поставлен диагноз до 50 лет, или тройной нативный рак груди, также могут увеличить ваш риск.
- Циклы родов и менструации: Если у вас не было доношенной беременности или у вас не было первого ребенка до 30 лет, у вас может быть более высокий риск заболеть раком груди. Начало менструации в возрасте до 12 лет и менопауза после 55 лет также может увеличить ваш риск.
- Образ жизни и экологические причины: Курение, употребление алкоголя, отсутствие физических упражнений, ИМТ более 25, хроническое воспаление, низкий уровень витамина D, чрезмерное пребывание на солнце или канцерогенных химических веществах и небезопасный секс могут способствовать развитию раковых клеток.

## Советы по профилактике рака молочной железы

Не существует проверенной стратегии профилактики, но формирование здорового образа жизни и принятие надлежащих мер по охране здоровья могут помочь снизить риск и повысить иммунитет. Недавние исследования показывают, что диета, по крайней мере, частично является причиной от 30 до 40% всех видов рака.

### 1. Избегать курения

Дым содержит канцерогенные соединения, которые могут вызвать рак. Это также делает вас более склонными к побочным эффектам, связанным с лечением. Если требуется облучение, вы можете столкнуться с повышенным риском развития рака легких и / или пневмонита.

### 2. Регулярно делайте физические упражнения

Физические упражнения помогают контролировать уровень сахара в крови и ограничивают уровень инсулина, гормона, который может влиять на рост клеток груди и развитие генетических мутаций, вызывающих рак. Старайтесь уделять не менее 150 минут в неделю умеренной аэробной активности или 75 минут интенсивной аэробной активности.

### 3. Поддерживайте здоровый вес (менее 25 ИМТ)

Жировые клетки производят эстроген, который может стимулировать развитие и рост некоторых типов рака груди. Избыточные жировые клетки также могут вызывать воспаление в организме, что увеличивает вероятность рецидива.

### 4. Соблюдайте диету для профилактики рака груди, выбирая:

- Придерживайтесь диеты, богатой фруктами и овощами.
- Выбирайте цельнозерновые, нежирные белки и обезжиренное молоко и молочные продукты.
- Удалите кожицу и жир с мяса, птицы и рыбы.
- Ограничьте сахар, рафинированные углеводы и алкоголь
- Ешьте меньшие порции

### 5. Избегайте вредного воздействия химикатов, токсинов, солнца и другого излучения

Начинаются новые исследования экологических причин рака груди и воздействия определенных химических веществ, содержащихся в пластике, косметике, продуктах питания, воде и других потребительских товарах. Также может сыграть роль использование пестицидов, антибиотиков и гормонов в производстве продуктов питания.

### 6. Запланировать ежегодные обследования груди

Раннее обнаружение по-прежнему является лучшим способом предотвратить рост или распространение рака. При 5-летней выживаемости около 100% при раке молочной железы стадии 0 и стадии 1 ключевым моментом является его раннее выявление.

### 7. Обратитесь к врачу, если у вас возникнут такие симптомы рака груди, как:

- Усталость
- Шишка или уплотнение на ощупь под кожей
- Непреднамеренная потеря или увеличение веса
- Изменения кожи, такие как пожелтение, потемнение или покраснение кожи
- Необъяснимое кровотечение, синяки или неизлечимые язвы
- Изменения в привычках кишечника или мочевого пузыря
- Постоянный кашель, затрудненное дыхание, несварение желудка или дискомфорт после еды
- Охриплость голоса или затруднение глотания
- Стойкая, необъяснимая лихорадка, ночная потливость или боль в мышцах и / или суставах

## Варианты профилактического лечения рака груди

Семейный анамнез рака груди и / или известной генетической мутации может вызывать стресс и беспокойство у многих женщин. Вместо того, чтобы ждать и смотреть, некоторые женщины предпочитают более активный и агрессивный подход, чтобы снизить свои шансы. Наиболее распространенными из них являются удаление груди и / или яичников и подавление гормона эстрогена, связанного с ростом раковых клеток. Хотя нет никакой гарантии, полезно ознакомиться с доступными вам видами профилактического лечения.

### Профилактическая мастэктомия

По данным Национального института рака, женщины, у которых есть BRCA1 or BRCA2 мутация гена и выбор профилактической мастэктомии могут снизить риск развития рака на 95%. Этот процент несколько снижается до 90% для женщин с сильным семейным анамнезом рака груди. Во время этой хирургической операции будут удалены одна или обе груди, чтобы снизить риск образования рака груди. Количество удаляемой ткани зависит от типа выполненной мастэктомии (например, тотальная, с сохранением кожи и соскосохранением). Реконструкция груди также может быть вариантом во время или после операции.

Подробнее

### Профилактическое удаление яичников

Этот тип хирургии дает женщинам возможность снизить риск, не вызывая серьезных видимых изменений в своем теле. Удаление яичников снижает количество эстрогена в организме, что помогает предотвратить рак груди, для роста которого требуется эстроген. Национальный институт рака обнаружил, что эта операция снижает количество новых случаев среди женщин из группы высокого риска примерно на 50%. Важно отметить, что этот тип хирургии приносит пользу только женщинам в пременопаузе и исключает возможность иметь детей.

Подробнее

### Профилактическая гормональная терапия

Этот тип лечения часто рекомендуется для тех, кому не был поставлен диагноз, но считается, что они подвержены риску ER- и PR-положительного рака груди. Определенные гормоны в крови могут вызывать эти раковые образования в ткани груди. Принимая эти гормоноблокирующие препараты, вы можете снизить выработку эстрогена в крови и остановить стимуляцию клеток груди. Гормональная терапия не влияет на опухоли, которые являются ER- и PR-отрицательными, потому что на них не влияют гормоны.

Подробнее

## Узнать больше о раке груди

Обследования и диагностика рака груди

Стадии и степени рака груди

Варианты лечения рака груди

English
Afrikaans Albanian Amharic Arabic Armenian Azerbaijani Basque Belarusian Bengali Bosnian Bulgarian Catalan Cebuano Chichewa Chinese (Simplified) Chinese (Traditional) Corsican Croatian Czech Danish Dutch English Esperanto Estonian Filipino Finnish French Frisian Galician Georgian German Greek Gujarati Haitian Creole Hausa Hawaiian Hebrew Hindi Hmong Hungarian Icelandic Igbo Indonesian Irish Italian Japanese Javanese Kannada Kazakh Khmer Korean Kurdish (Kurmanji) Kyrgyz Lao Latin Latvian Lithuanian Luxembourgish Macedonian Malagasy Malay Malayalam Maltese Maori Marathi Mongolian Myanmar (Burmese) Nepali Norwegian Pashto Persian Polish Portuguese Punjabi Romanian Russian Samoan Scottish Gaelic Serbian Sesotho Shona Sindhi Sinhala Slovak Slovenian Somali Spanish Sudanese Swahili Swedish Tajik Tamil Telugu Thai Turkish Ukrainian Urdu Uzbek Vietnamese Welsh Xhosa Yiddish Yoruba Zulu

## Свяжитесь с нами

Имя*
Фамилия*
Ваш e-mail*
Номер телефона*
Как вы узнали о нас?*
Сообщение

## Регистрация

- Имя*
- Фамилия*
- Название*
- Если Другое, укажите, пожалуйста
- Присоединение*
- Адрес улицы Адрес Line 2 Город Область
  Почтовый индекс
- Эл. адрес*
- Специальные
- Если Другое, укажите, пожалуйста
- Как вы узнали об этой деятельности?
  - Брошюра / Открытка по почте
  - Объявление по электронной почте
  - Личное письмо / приглашение
  - Директор / Руководитель
  - Другое
- Если Другое, укажите, пожалуйста
- Эл. адрес
  Это поле для целей проверки и должны быть оставлены без изменений.